# Contributing to pyfixest

Thanks for taking the time to contribute! We appreciate all contributions, from reporting bugs to implementing new features.

Please refer to the [contributing section](https://py-econometrics.github.io/pyfixest/contributing.html) of our documentation to get started.

We look forward to your contributions!
